# coding: utf-8

"""
    Warg Registry API

    [warg](https://warg.io/) is an open source protocol for WebAssembly component registries. 

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json



from pydantic import BaseModel, Field, StrictInt, StrictStr, constr, validator

class IncorrectProofError(BaseModel):
    """
    IncorrectProofError
    """
    status: StrictInt = Field(default=..., description="The HTTP status code for the error.")
    reason: StrictStr = Field(default=..., description="The reason why the bundle could not be generated.")
    root: constr(strict=True) = Field(default=..., description="Represents a supported hash.")
    found: constr(strict=True) = Field(default=..., description="Represents a supported hash.")
    __properties = ["status", "reason", "root", "found"]

    @validator('reason')
    def reason_validate_enum(cls, value):
        """Validates the enum"""
        if value not in ('incorrectProof',):
            raise ValueError("must be one of enum values ('incorrectProof')")
        return value

    @validator('root')
    def root_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if not re.match(r"^[a-z0-9-]+:[a-f0-9]+$", value):
            raise ValueError(r"must validate the regular expression /^[a-z0-9-]+:[a-f0-9]+$/")
        return value

    @validator('found')
    def found_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if not re.match(r"^[a-z0-9-]+:[a-f0-9]+$", value):
            raise ValueError(r"must validate the regular expression /^[a-z0-9-]+:[a-f0-9]+$/")
        return value

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> IncorrectProofError:
        """Create an instance of IncorrectProofError from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> IncorrectProofError:
        """Create an instance of IncorrectProofError from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return IncorrectProofError.parse_obj(obj)

        _obj = IncorrectProofError.parse_obj({
            "status": obj.get("status"),
            "reason": obj.get("reason"),
            "root": obj.get("root"),
            "found": obj.get("found")
        })
        return _obj


