# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: proto/warg/protocol/warg.proto
# Protobuf Python Version: 6.32.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    1,
    '',
    'proto/warg/protocol/warg.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1eproto/warg/protocol/warg.proto\x12\rwarg.protocol\x1a\x1fgoogle/protobuf/timestamp.proto\"?\n\x08\x45nvelope\x12\x10\n\x08\x63ontents\x18\x01 \x01(\x0c\x12\x0e\n\x06key_id\x18\x02 \x01(\t\x12\x11\n\tsignature\x18\x03 \x01(\t\"\x96\x01\n\x0eOperatorRecord\x12\x11\n\x04prev\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x0f\n\x07version\x18\x02 \x01(\r\x12(\n\x04time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12-\n\x07\x65ntries\x18\x04 \x03(\x0b\x32\x1c.warg.protocol.OperatorEntryB\x07\n\x05_prev\"\xc2\x02\n\rOperatorEntry\x12+\n\x04init\x18\x01 \x01(\x0b\x32\x1b.warg.protocol.OperatorInitH\x00\x12\x36\n\ngrant_flat\x18\x02 \x01(\x0b\x32 .warg.protocol.OperatorGrantFlatH\x00\x12\x38\n\x0brevoke_flat\x18\x03 \x01(\x0b\x32!.warg.protocol.OperatorRevokeFlatH\x00\x12\x42\n\x10\x64\x65\x66ine_namespace\x18\x04 \x01(\x0b\x32&.warg.protocol.OperatorDefineNamespaceH\x00\x12\x42\n\x10import_namespace\x18\x05 \x01(\x0b\x32&.warg.protocol.OperatorImportNamespaceH\x00\x42\n\n\x08\x63ontents\"3\n\x0cOperatorInit\x12\x16\n\x0ehash_algorithm\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\"X\n\x11OperatorGrantFlat\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x36\n\x0bpermissions\x18\x02 \x03(\x0e\x32!.warg.protocol.OperatorPermission\"\\\n\x12OperatorRevokeFlat\x12\x0e\n\x06key_id\x18\x01 \x01(\t\x12\x36\n\x0bpermissions\x18\x02 \x03(\x0e\x32!.warg.protocol.OperatorPermission\",\n\x17OperatorDefineNamespace\x12\x11\n\tnamespace\x18\x01 \x01(\t\">\n\x17OperatorImportNamespace\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x10\n\x08registry\x18\x02 \x01(\t\"\x94\x01\n\rPackageRecord\x12\x11\n\x04prev\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x0f\n\x07version\x18\x02 \x01(\r\x12(\n\x04time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x07\x65ntries\x18\x04 \x03(\x0b\x32\x1b.warg.protocol.PackageEntryB\x07\n\x05_prev\"\x94\x02\n\x0cPackageEntry\x12*\n\x04init\x18\x01 \x01(\x0b\x32\x1a.warg.protocol.PackageInitH\x00\x12\x35\n\ngrant_flat\x18\x02 \x01(\x0b\x32\x1f.warg.protocol.PackageGrantFlatH\x00\x12\x37\n\x0brevoke_flat\x18\x03 \x01(\x0b\x32 .warg.protocol.PackageRevokeFlatH\x00\x12\x30\n\x07release\x18\x04 \x01(\x0b\x32\x1d.warg.protocol.PackageReleaseH\x00\x12*\n\x04yank\x18\x05 \x01(\x0b\x32\x1a.warg.protocol.PackageYankH\x00\x42\n\n\x08\x63ontents\"2\n\x0bPackageInit\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x16\n\x0ehash_algorithm\x18\x02 \x01(\t\"V\n\x10PackageGrantFlat\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x35\n\x0bpermissions\x18\x02 \x03(\x0e\x32 .warg.protocol.PackagePermission\"Z\n\x11PackageRevokeFlat\x12\x0e\n\x06key_id\x18\x01 \x01(\t\x12\x35\n\x0bpermissions\x18\x02 \x03(\x0e\x32 .warg.protocol.PackagePermission\"7\n\x0ePackageRelease\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x14\n\x0c\x63ontent_hash\x18\x02 \x01(\t\"\x1e\n\x0bPackageYank\x12\x0f\n\x07version\x18\x01 \x01(\t*\xad\x01\n\x12OperatorPermission\x12#\n\x1fOPERATOR_PERMISSION_UNSPECIFIED\x10\x00\x12\x1e\n\x1aOPERATOR_PERMISSION_COMMIT\x10\x01\x12(\n$OPERATOR_PERMISSION_DEFINE_NAMESPACE\x10\x02\x12(\n$OPERATOR_PERMISSION_IMPORT_NAMESPACE\x10\x03*t\n\x11PackagePermission\x12\"\n\x1ePACKAGE_PERMISSION_UNSPECIFIED\x10\x00\x12\x1e\n\x1aPACKAGE_PERMISSION_RELEASE\x10\x01\x12\x1b\n\x17PACKAGE_PERMISSION_YANK\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'proto.warg.protocol.warg_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_OPERATORPERMISSION']._serialized_start=1724
  _globals['_OPERATORPERMISSION']._serialized_end=1897
  _globals['_PACKAGEPERMISSION']._serialized_start=1899
  _globals['_PACKAGEPERMISSION']._serialized_end=2015
  _globals['_ENVELOPE']._serialized_start=82
  _globals['_ENVELOPE']._serialized_end=145
  _globals['_OPERATORRECORD']._serialized_start=148
  _globals['_OPERATORRECORD']._serialized_end=298
  _globals['_OPERATORENTRY']._serialized_start=301
  _globals['_OPERATORENTRY']._serialized_end=623
  _globals['_OPERATORINIT']._serialized_start=625
  _globals['_OPERATORINIT']._serialized_end=676
  _globals['_OPERATORGRANTFLAT']._serialized_start=678
  _globals['_OPERATORGRANTFLAT']._serialized_end=766
  _globals['_OPERATORREVOKEFLAT']._serialized_start=768
  _globals['_OPERATORREVOKEFLAT']._serialized_end=860
  _globals['_OPERATORDEFINENAMESPACE']._serialized_start=862
  _globals['_OPERATORDEFINENAMESPACE']._serialized_end=906
  _globals['_OPERATORIMPORTNAMESPACE']._serialized_start=908
  _globals['_OPERATORIMPORTNAMESPACE']._serialized_end=970
  _globals['_PACKAGERECORD']._serialized_start=973
  _globals['_PACKAGERECORD']._serialized_end=1121
  _globals['_PACKAGEENTRY']._serialized_start=1124
  _globals['_PACKAGEENTRY']._serialized_end=1400
  _globals['_PACKAGEINIT']._serialized_start=1402
  _globals['_PACKAGEINIT']._serialized_end=1452
  _globals['_PACKAGEGRANTFLAT']._serialized_start=1454
  _globals['_PACKAGEGRANTFLAT']._serialized_end=1540
  _globals['_PACKAGEREVOKEFLAT']._serialized_start=1542
  _globals['_PACKAGEREVOKEFLAT']._serialized_end=1632
  _globals['_PACKAGERELEASE']._serialized_start=1634
  _globals['_PACKAGERELEASE']._serialized_end=1689
  _globals['_PACKAGEYANK']._serialized_start=1691
  _globals['_PACKAGEYANK']._serialized_end=1721
# @@protoc_insertion_point(module_scope)
