# coding: utf-8

"""
    Warg Registry API

    [warg](https://warg.io/) is an open source protocol for WebAssembly component registries. 

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Any, Dict, Optional
from pydantic import BaseModel, Field, conint, constr, validator

class FetchLogsRequest(BaseModel):
    """
    A request to fetch logs from the registry.  # noqa: E501
    """
    log_length: conint(strict=True, ge=1) = Field(default=..., alias="logLength", description="The registry checkpoint log length to fetch from.")
    limit: Optional[conint(strict=True, le=1000, ge=1)] = Field(default=100, description="The limit of operator and packages records to return for the fetch request.")
    operator: Optional[constr(strict=True)] = Field(default=None, description="Represents a supported hash.")
    packages: Optional[Dict[str, Any]] = Field(default=None, description="The map of package log identifier to last known package record fetch token.  If the last package record identifier is null, records are returned from the start of the log. ")
    additional_properties: Dict[str, Any] = {}
    __properties = ["logLength", "limit", "operator", "packages"]

    @validator('operator')
    def operator_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if value is None:
            return value

        if not re.match(r"^[a-z0-9-]+:[a-f0-9]+$", value):
            raise ValueError(r"must validate the regular expression /^[a-z0-9-]+:[a-f0-9]+$/")
        return value

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> FetchLogsRequest:
        """Create an instance of FetchLogsRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                            "additional_properties"
                          },
                          exclude_none=True)
        # puts key-value pairs in additional_properties in the top level
        if self.additional_properties is not None:
            for _key, _value in self.additional_properties.items():
                _dict[_key] = _value

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> FetchLogsRequest:
        """Create an instance of FetchLogsRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return FetchLogsRequest.parse_obj(obj)

        _obj = FetchLogsRequest.parse_obj({
            "log_length": obj.get("logLength"),
            "limit": obj.get("limit") if obj.get("limit") is not None else 100,
            "operator": obj.get("operator"),
            "packages": obj.get("packages")
        })
        # store additional fields in additional_properties
        for _key in obj.keys():
            if _key not in cls.__properties:
                _obj.additional_properties[_key] = obj.get(_key)

        return _obj


