# coding: utf-8

"""
    Warg Registry API

    [warg](https://warg.io/) is an open source protocol for WebAssembly component registries. 

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictInt, StrictStr, validator

class CheckpointVerificationResponse(BaseModel):
    """
    CheckpointVerificationResponse
    """
    checkpoint: StrictStr = Field(default=..., description="The verification of the checkpoint's `logLength`, `logRoot` and `mapRoot`:    * `unverified`: checkpoint may be valid or invalid; if `retryAfter` is provided, the client should retry the request;   * `verified`: `logLength`, `logRoot` and `mapRoot` are verified;   * `invalid`: checkpoint with the specified `logLength` was either not produced or does not match the correct `logRoot` and `mapRoot`; ")
    signature: StrictStr = Field(default=..., description="The verification of the checkpoint's `keyId` and `signature`:    * `unverified`: checkpoint's `signature` may be valid or invalid; if `retryAfter` is provided, the client should retry the request;   * `verified`: checkpoint's `signature` is verified;   * `invalid`: `keyId` is not known or does not have authorization (could have been revoke or never granted) to sign checkpoints or the `signature` itself is invalid; ")
    retry_after: Optional[StrictInt] = Field(default=None, alias="retryAfter", description="If either `checkpoint` or `signature` is `unverified` status, then the server may instruct the client to retry the request after the specified number of seconds.")
    __properties = ["checkpoint", "signature", "retryAfter"]

    @validator('checkpoint')
    def checkpoint_validate_enum(cls, value):
        """Validates the enum"""
        if value not in ('unverified', 'verified', 'invalid',):
            raise ValueError("must be one of enum values ('unverified', 'verified', 'invalid')")
        return value

    @validator('signature')
    def signature_validate_enum(cls, value):
        """Validates the enum"""
        if value not in ('unverified', 'verified', 'invalid',):
            raise ValueError("must be one of enum values ('unverified', 'verified', 'invalid')")
        return value

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> CheckpointVerificationResponse:
        """Create an instance of CheckpointVerificationResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> CheckpointVerificationResponse:
        """Create an instance of CheckpointVerificationResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return CheckpointVerificationResponse.parse_obj(obj)

        _obj = CheckpointVerificationResponse.parse_obj({
            "checkpoint": obj.get("checkpoint"),
            "signature": obj.get("signature"),
            "retry_after": obj.get("retryAfter")
        })
        return _obj


