# coding: utf-8

"""
    Warg Registry API

    [warg](https://warg.io/) is an open source protocol for WebAssembly component registries. 

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json



from pydantic import BaseModel, Field, conint, constr, validator

class Checkpoint(BaseModel):
    """
    A registry checkpoint.  Checkpoints are hashed by concatenating the following:   * A prefix of the byte string `WARG-CHECKPOINT-V0`   * The LEB128-encoded `logLength`   * The LEB128-length-prefixed `logRoot`   * The LEB128-length-prefixed `mapRoot`   # noqa: E501
    """
    log_length: conint(strict=True, ge=1) = Field(default=..., alias="logLength", description="The log length of the checkpoint.")
    log_root: constr(strict=True) = Field(default=..., alias="logRoot", description="Represents a supported hash.")
    map_root: constr(strict=True) = Field(default=..., alias="mapRoot", description="Represents a supported hash.")
    __properties = ["logLength", "logRoot", "mapRoot"]

    @validator('log_root')
    def log_root_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if not re.match(r"^[a-z0-9-]+:[a-f0-9]+$", value):
            raise ValueError(r"must validate the regular expression /^[a-z0-9-]+:[a-f0-9]+$/")
        return value

    @validator('map_root')
    def map_root_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if not re.match(r"^[a-z0-9-]+:[a-f0-9]+$", value):
            raise ValueError(r"must validate the regular expression /^[a-z0-9-]+:[a-f0-9]+$/")
        return value

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Checkpoint:
        """Create an instance of Checkpoint from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> Checkpoint:
        """Create an instance of Checkpoint from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return Checkpoint.parse_obj(obj)

        _obj = Checkpoint.parse_obj({
            "log_length": obj.get("logLength"),
            "log_root": obj.get("logRoot"),
            "map_root": obj.get("mapRoot")
        })
        return _obj


