# coding: utf-8

"""
    Warg Registry API

    [warg](https://warg.io/) is an open source protocol for WebAssembly component registries. 

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json



from pydantic import BaseModel, Field, constr, validator
from warg_openapi.models.timestamped_checkpoint import TimestampedCheckpoint

class SignedCheckpoint(BaseModel):
    """
    A signed registry checkpoint.  # noqa: E501
    """
    key_id: constr(strict=True) = Field(default=..., alias="keyId", description="Represents a supported hash.")
    signature: constr(strict=True) = Field(default=..., description="The algorithm-prefixed bytes of the signature (base64 encoded).")
    contents: TimestampedCheckpoint = Field(...)
    __properties = ["keyId", "signature", "contents"]

    @validator('key_id')
    def key_id_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if not re.match(r"^[a-z0-9-]+:[a-f0-9]+$", value):
            raise ValueError(r"must validate the regular expression /^[a-z0-9-]+:[a-f0-9]+$/")
        return value

    @validator('signature')
    def signature_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if not re.match(r"^[a-z0-9-]+:(?:[A-Za-z0-9+\/]{4})*(?:[A-Za-z0-9+\/]{4}|[A-Za-z0-9+\/]{3}=|[A-Za-z0-9+\/]{2}={2})$", value):
            raise ValueError(r"must validate the regular expression /^[a-z0-9-]+:(?:[A-Za-z0-9+\/]{4})*(?:[A-Za-z0-9+\/]{4}|[A-Za-z0-9+\/]{3}=|[A-Za-z0-9+\/]{2}={2})$/")
        return value

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> SignedCheckpoint:
        """Create an instance of SignedCheckpoint from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of contents
        if self.contents:
            _dict['contents'] = self.contents.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> SignedCheckpoint:
        """Create an instance of SignedCheckpoint from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return SignedCheckpoint.parse_obj(obj)

        _obj = SignedCheckpoint.parse_obj({
            "key_id": obj.get("keyId"),
            "signature": obj.get("signature"),
            "contents": TimestampedCheckpoint.from_dict(obj.get("contents")) if obj.get("contents") is not None else None
        })
        return _obj


