# coding: utf-8

"""
    Warg Registry API

    [warg](https://warg.io/) is an open source protocol for WebAssembly component registries. 

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictStr, validator
from warg_openapi.models.http_upload_headers import HttpUploadHeaders

class HttpUpload(BaseModel):
    """
    A HTTP upload endpoint.  # noqa: E501
    """
    type: StrictStr = Field(default=..., description="The type of upload endpoint.")
    method: StrictStr = Field(default=..., description="The HTTP method for the upload request. Uppercase is required.")
    url: StrictStr = Field(default=..., description="The URL of the upload endpoint, which may be relative to the API base URL.")
    headers: Optional[HttpUploadHeaders] = None
    __properties = ["type", "method", "url", "headers"]

    @validator('type')
    def type_validate_enum(cls, value):
        """Validates the enum"""
        if value not in ('http',):
            raise ValueError("must be one of enum values ('http')")
        return value

    @validator('method')
    def method_validate_enum(cls, value):
        """Validates the enum"""
        if value not in ('POST', 'PUT',):
            raise ValueError("must be one of enum values ('POST', 'PUT')")
        return value

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> HttpUpload:
        """Create an instance of HttpUpload from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of headers
        if self.headers:
            _dict['headers'] = self.headers.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> HttpUpload:
        """Create an instance of HttpUpload from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return HttpUpload.parse_obj(obj)

        _obj = HttpUpload.parse_obj({
            "type": obj.get("type"),
            "method": obj.get("method"),
            "url": obj.get("url"),
            "headers": HttpUploadHeaders.from_dict(obj.get("headers")) if obj.get("headers") is not None else None
        })
        return _obj


