# coding: utf-8

"""
    Warg Registry API

    [warg](https://warg.io/) is an open source protocol for WebAssembly component registries. 

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json



from pydantic import BaseModel, Field, StrictInt, StrictStr, validator

class ProveInclusion404Response(BaseModel):
    """
    ProveInclusion404Response
    """
    status: StrictInt = Field(default=..., description="The HTTP status code for the error.")
    type: StrictStr = Field(default=..., description="The type of entity that was not found.")
    id: StrictInt = Field(default=..., description="The identifier of the entity that was not found.")
    additional_properties: Dict[str, Any] = {}
    __properties = ["status", "type", "id"]

    @validator('type')
    def type_validate_enum(cls, value):
        """Validates the enum"""
        if value not in ('logLength', 'leaf',):
            raise ValueError("must be one of enum values ('logLength', 'leaf')")
        return value

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ProveInclusion404Response:
        """Create an instance of ProveInclusion404Response from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                            "additional_properties"
                          },
                          exclude_none=True)
        # puts key-value pairs in additional_properties in the top level
        if self.additional_properties is not None:
            for _key, _value in self.additional_properties.items():
                _dict[_key] = _value

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ProveInclusion404Response:
        """Create an instance of ProveInclusion404Response from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ProveInclusion404Response.parse_obj(obj)

        _obj = ProveInclusion404Response.parse_obj({
            "status": obj.get("status"),
            "type": obj.get("type"),
            "id": obj.get("id")
        })
        # store additional fields in additional_properties
        for _key in obj.keys():
            if _key not in cls.__properties:
                _obj.additional_properties[_key] = obj.get(_key)

        return _obj


