# coding: utf-8

"""
    Warg Registry API

    [warg](https://warg.io/) is an open source protocol for WebAssembly component registries. 

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictBool, StrictInt, StrictStr, validator

class LedgerSourcesResponseSourcesInner(BaseModel):
    """
    Ledger source HTTP get URL.  # noqa: E501
    """
    first_registry_index: StrictInt = Field(default=..., alias="firstRegistryIndex", description="The first registry index included in the source.")
    last_registry_index: StrictInt = Field(default=..., alias="lastRegistryIndex", description="The last registry index included in the source.")
    url: StrictStr = Field(default=..., description="The HTTP GET URL to fetch the source.")
    content_type: StrictStr = Field(default=..., alias="contentType", description="The content type of source.")
    accept_ranges: Optional[StrictBool] = Field(default=None, alias="acceptRanges", description="Flag indicating if the server accepts byte ranges with `Range` header.")
    __properties = ["firstRegistryIndex", "lastRegistryIndex", "url", "contentType", "acceptRanges"]

    @validator('content_type')
    def content_type_validate_enum(cls, value):
        """Validates the enum"""
        if value not in ('application/vnd.warg.ledger.packed',):
            raise ValueError("must be one of enum values ('application/vnd.warg.ledger.packed')")
        return value

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> LedgerSourcesResponseSourcesInner:
        """Create an instance of LedgerSourcesResponseSourcesInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> LedgerSourcesResponseSourcesInner:
        """Create an instance of LedgerSourcesResponseSourcesInner from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return LedgerSourcesResponseSourcesInner.parse_obj(obj)

        _obj = LedgerSourcesResponseSourcesInner.parse_obj({
            "first_registry_index": obj.get("firstRegistryIndex"),
            "last_registry_index": obj.get("lastRegistryIndex"),
            "url": obj.get("url"),
            "content_type": obj.get("contentType"),
            "accept_ranges": obj.get("acceptRanges")
        })
        return _obj


